@@ -1269,7 +1269,7 @@ class LegistarScraper:
             date using ev_date and time using ev_time
         """
         # 2021-07-09T00:00:00
-        d = datetime.strptime(ev_date, LEGISTAR_DATETIME_FORMAT)
+        d = datetime.fromisoformat(ev_date)
         # 9:30 AM
         # some events may have ev_time =None
         if ev_time is not None:
@@ -1390,20 +1390,32 @@ class LegistarScraper:
             # EventMinutesItem.votes.person
             for minute_item in event.event_minutes_items:
                 if minute_item.matter and minute_item.matter.sponsors:
-                    minute_item.matter.sponsors = [
-                        self.inject_known_person(sponsor)
-                        for sponsor in minute_item.matter.sponsors
-                    ]
-                if minute_item.votes:
-                    minute_item.votes = [
-                        Vote(
-                            decision=vote.decision,
-                            external_source_id=vote.external_source_id,
-                            person=self.inject_known_person(vote.person),
-                        )
-                        for vote in minute_item.votes
-                    ]
+                    for sponsor in minute_item.matter.sponsors:
+                        sponsor = self.inject_known_person(sponsor)
 
+                if minute_item.votes:
+                    for vote in minute_item.votes:
+                        vote.person = self.inject_known_person(vote.person)
+
+        return events
+
+    def post_process_ingestion_models(
+        self, events: List[EventIngestionModel]
+    ) -> List[EventIngestionModel]:
+        """
+        Called at the end of get_events() for fully custom site-specific prcessing.
+        inject_known_data() already operated on input events.
+
+        Parameters
+        ----------
+        events:
+            Returned events from get_events()
+
+        Returns
+        -------
+        events: List[EventIngestionModel]
+            Base implementation simply returns input events as-is
+        """
         return events
 
     def get_events(
@@ -1467,32 +1479,30 @@ class LegistarScraper:
                     ContentURIs(video_uri=None, caption_uri=None)
                 ]
 
-            sessions = []
-            sessions = reduced_list(
-                [
-                    self.get_none_if_empty(
-                        Session(
-                            session_datetime=session_time,
-                            session_index=len(sessions),
-                            video_uri=content_uris.video_uri,
-                            caption_uri=content_uris.caption_uri,
-                        )
-                    )
-                    # Session per video
-                    for content_uris in list_uri
-                ]
-            )
             ingestion_models.append(
                 self.get_none_if_empty(
                     EventIngestionModel(
                         external_source_id=str(legistar_ev[LEGISTAR_EV_EXT_ID]),
                         agenda_uri=str_simplified(legistar_ev[LEGISTAR_AGENDA_URI]),
                         minutes_uri=str_simplified(legistar_ev[LEGISTAR_MINUTES_URI]),
-                        sessions=sessions,
+                        body=self.get_body(legistar_ev[LEGISTAR_EV_BODY]),
+                        sessions=reduced_list(
+                            [
+                                self.get_none_if_empty(
+                                    Session(
+                                        session_datetime=session_time,
+                                        session_index=list_uri.index(content_uris),
+                                        video_uri=content_uris.video_uri,
+                                        caption_uri=content_uris.caption_uri,
+                                    )
+                                )
+                                # Session per video
+                                for content_uris in list_uri
+                            ]
+                        ),
                         event_minutes_items=self.get_event_minutes(
                             legistar_ev[LEGISTAR_EV_ITEMS]
                         ),
-                        body=self.get_body(legistar_ev[LEGISTAR_EV_BODY]),
                     )
                 )
             )
@@ -1501,6 +1511,7 @@ class LegistarScraper:
         # so request reduced_list() to give me [], not None
         events = reduced_list(ingestion_models, collapse=False)
         events = self.inject_known_data(events)
+        events = self.post_process_ingestion_models(events)
 
         return events
 
